'''This generator provides service mappings'''
__revision__ = '$Revision: 5477 $'

import Bcfg2.Server.Plugin


class Svcmgr(Bcfg2.Server.Plugin.PrioDir):
    '''This is a generator that handles service assignments'''
    name = 'Svcmgr'
    __version__ = '$Id: Svcmgr.py 5477 2009-10-07 14:46:08Z solj $'
    __author__ = 'bcfg-dev@mcs.anl.gov'
    deprecated = True
